@@ -17,6 +17,10 @@ from redshift_client.id_objs import (
     SchemaId,
     TableId,
 )
+from redshift_client.schema.core import (
+    Quota,
+    SchemaPolicy,
+)
 from redshift_client.sql_client.core import (
     SqlClient,
 )
@@ -109,3 +113,42 @@ class SchemaClient:
             ),
             None,
         )
+
+    def create(
+        self, schema: SchemaId, if_not_exist: bool = False
+    ) -> Cmd[None]:
+        not_exist = " IF NOT EXISTS " if if_not_exist else ""
+        stm = f"CREATE SCHEMA {not_exist} {{schema}}"
+        return self._db_client.execute(
+            dynamic_query(stm, FrozenDict({"schema": schema.name})), None
+        )
+
+    def set_policy(self, schema: SchemaId, policy: SchemaPolicy) -> Cmd[None]:
+        stm = "ALTER SCHEMA {schema} OWNER TO {owner}"
+        stm2 = (
+            f"ALTER SCHEMA {{schema}} QUOTA %(quota)s {policy.quota.unit.value}"
+            if isinstance(policy.quota, Quota)
+            else "ALTER SCHEMA {schema} QUOTA UNLIMITED"
+        )
+        set_owner = self._db_client.execute(
+            dynamic_query(
+                stm, FrozenDict({"schema": schema.name, "owner": policy.owner})
+            ),
+            None,
+        )
+        set_quota = self._db_client.execute(
+            dynamic_query(
+                stm2,
+                FrozenDict(
+                    {
+                        "schema": schema.name,
+                    }
+                ),
+            ),
+            FrozenDict(
+                {"quota": policy.quota.value}
+                if isinstance(policy.quota, Quota)
+                else {}
+            ),
+        )
+        return set_owner + set_quota
