@@ -33,6 +33,8 @@ def _assert_opt_int(val: PrimitiveVal) -> ResultE[Optional[int]]:
             return Result.success(int(val))
         except ValueError as err:
             return Result.failure(err)
+    if val is None:
+        return Result.success(None)
     return Result.failure(ValueError("not a int|str"))
 
 
