@@ -98,11 +98,10 @@ class TableClient:
                         ELSE numeric_precision end AS max_length,
                 numeric_scale,
                 is_nullable,
-                column_default AS default_value,
+                column_default AS default_value
             FROM information_schema.columns
             WHERE table_name = %(table_name)s
                 AND table_schema = %(table_schema)s
-            ORDER BY ordinal_position;
         """
 
         exe = self._db_client.execute(
@@ -136,7 +135,7 @@ class TableClient:
             [
                 f"""
                     {{name_{n}}} {_encode_data_type(c.data_type)}
-                    DEFAULT {c.default} {encode_nullable(c.nullable)}
+                    DEFAULT %(default_{n})s {encode_nullable(c.nullable)}
                 """
                 for n, (_, c) in enum_columns
             ]
@@ -150,7 +149,9 @@ class TableClient:
             identifiers[f"pkey_{index}"] = cid.name
         for index, (cid, _) in enum_columns:
             identifiers[f"name_{index}"] = cid.name
-
+        values = FrozenDict(
+            {f"default_{index}": c.default for index, (_, c) in enum_columns}
+        )
         return self._db_client.execute(
-            dynamic_query(stm, FrozenDict(identifiers)), None
+            dynamic_query(stm, FrozenDict(identifiers)), values
         )
